''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''
'                                VBDEMO.BAS                             '
'                 ODBC Visual Basic Sample Application                '
'                                                                      '
' -- (C) Copyright 1991, 1992 by Microsoft Corporation                                        '
'                                                                      '
' Uses ODBC drivers, June 1992 Spec                                     '
'                                                                      '
''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''

''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''
' VBDEMO consists of the following source files:
'
' VBDEMO.BAS    -- Constants, DLL and API declarations, and global variables
'                 used to maintain connection and statement handles.
'
' GRIDCTL.BAS  -- Maintains and displays a "grid control", include routines
'                 to store, retrieve, and display data.  Could easily be
'                 used with another application.
'
' MISCPROC.BAS -- Procedures to manage connections, and to fill "grid control"
'                 with data.  Could be used with another application with
'                 some modification.
'
' QUERY.FRM    -- The main form, allows users to enter SQL queries and
'                 view results.
'
' LOGON.FRM    -- Allows user to establish a connection to a data base
'
' BUFSZFOR.FRM -- Allows user to change the grid buffer size
'
' SQLABOUT.FRM -- Displays "About VBDEMO" message box

''''''''''''''''''''
' GLOBAL CONSTANTS '
''''''''''''''''''''

''''''''''''''''
' Convenient Global Constants

Global Const AppName = "VB Demo"
Global Const StopIcon = 16
Global Const QuIcon = 32
Global Const AttIcon = 48
Global Const InfoIcon = 64
Global Const HourGlass = 11
Global Const Normal = 0
Global Const PixelScale = 3
Global Const SolidFill = 1
Global Const ShowModal = 1

Global Const ASCII_CR = 13
Global Const ASCII_ESC = 27

Global Const KEY_PRIOR = &H21
Global Const KEY_NEXT = &H22
Global Const KEY_END = &H23
Global Const KEY_HOME = &H24
Global Const KEY_LEFT = &H25
Global Const KEY_UP = &H26
Global Const KEY_RIGHT = &H27
Global Const KEY_DOWN = &H28
Global Const KEY_SELECT = &H29

Global Const ACTIVE_TITLE_BAR = &H80000002      ' Active window caption.
Global Const INACTIVE_TITLE_BAR = &H80000003    ' Inactive window caption.

'''''''''''''''
' Miscellaneous Constants

Global Const Inactive = 0
Global Const Active = 1
'Global Const True = -1
'Global Const False = 0

Global Const SBufferLen = 256            ' Default String Buffer Length

''''''''''''''''
' Connection Management Constants and Data Structures

Global Const MaxConnections = 16

Type ConnectionInfo
  hdbc As Long                        ' Connection handle
  hstmt As Long                       ' Statement handle
  Status As Integer                   ' Active or Inactive
  Tag As String                       ' A string of the form "DataSource <number>"
				      ' uniquely identifying a connection
End Type
				       
Global Connection(1 To MaxConnections) As ConnectionInfo
Global NumConnections As Integer
Global henv As Long
 
''''''''''''''''
' ODBC Declarations and Constants

Global Const SQL_SUCCESS = 0
Global Const SQL_SUCCESS_WITH_INFO = 1
Global Const SQL_ERROR = -1
Global Const SQL_NO_DATA_FOUND = 100
Global Const SQL_CLOSE = 0
Global Const SQL_CHAR = 1
Global Const SQL_NUMERIC = 2
Global Const SQL_DECIMAL = 3
Global Const SQL_INTEGER = 4
Global Const SQL_SMALLINT = 5
Global Const SQL_FLOAT = 6
Global Const SQL_REAL = 7
Global Const SQL_DOUBLE = 8
Global Const SQL_VARCHAR = 12
Global Const SQL_DATA_SOURCE_NAME = 6
Global Const SQL_USER_NAME = 8


Declare Function SQLAllocEnv Lib "odbc.dll" (env As Long) As Integer
Declare Function SQLFreeEnv Lib "odbc.dll" (ByVal env As Long) As Integer

Declare Function SQLAllocConnect Lib "odbc.dll" (ByVal env As Long, hdbc As Long) As Integer
Declare Function SQLConnect Lib "odbc.dll" (ByVal hdbc As Long, ByVal Server As String, ByVal serverlen As Integer, ByVal uid As String, ByVal uidlen As Integer, ByVal pwd As String, ByVal pwdlen As Integer) As Integer
Declare Function SQLDriverConnect Lib "odbc.dll" (ByVal hdbc As Long, ByVal hwnd As Integer, ByVal szCSIn As String, ByVal cbCSIn As Integer, ByVal szCSOut As String, ByVal cbCSMax As Integer, cbCSOut As Integer, ByVal f As Integer) As Integer

Declare Function SQLFreeConnect Lib "odbc.dll" (ByVal hdbc As Long) As Integer
Declare Function SQLDisconnect Lib "odbc.dll" (ByVal hdbc As Long) As Integer
Declare Function SQLAllocStmt Lib "odbc.dll" (ByVal hdbc As Long, hstmt As Long) As Integer
Declare Function SQLFreeStmt Lib "odbc.dll" (ByVal hstmt As Long, ByVal EndOption As Integer) As Integer
Declare Function SQLTables Lib "odbc.dll" (ByVal hstmt As Long, ByVal q As Long, ByVal cbq As Integer, ByVal o As Long, ByVal cbo As Integer, ByVal t As Long, ByVal cbt As Integer, ByVal tt As Long, ByVal cbtt As Integer) As Integer
Declare Function SQLGetInfo Lib "odbc.dll" (ByVal hdbc As Long, ByVal hwnd As Integer, ByVal szInfo As String, ByVal cbInfoMax As Integer, cbInfoOut As Integer) As Integer

Declare Function SQLExecDirect Lib "odbc.dll" (ByVal hstmt As Long, ByVal sqlString As String, ByVal sqlstrlen As Long) As Integer
Declare Function SQLExecute Lib "odbc.dll" (ByVal hstmt As Long) As Integer
Declare Function SQLPrepare Lib "odbc.dll" (ByVal hstmt As Long, ByVal sqlString As String, ByVal sqlstrlen As Long) As Integer
Declare Function SQLNumREsultCols Lib "odbc.dll" (ByVal hstmt As Long, NumCols As Integer) As Integer
Declare Function SQLDescribeCol Lib "odbc.dll" (ByVal hstmt As Long, ByVal colnum As Integer, ByVal colname As String, ByVal Buflen As Integer, colnamelen As Integer, dtype As Integer, dl As Long, ds As Integer, n As Integer) As Integer
Declare Function SQLFetch Lib "odbc.dll" (ByVal hstmt As Long) As Integer
Declare Function SQLGetData Lib "odbc.dll" (ByVal hstmt As Long, ByVal col As Integer, ByVal wConvType As Integer, ByVal lpbBuf As String, ByVal dwbuflen As Long, lpcbout As Long) As Integer
Declare Function SQLError Lib "odbc.dll" (ByVal env As Long, ByVal hdbc As Long, ByVal hstmt As Long, ByVal SQLState As String, NativeError As Long, ByVal Buffer As String, ByVal Buflen As Integer, Outlen As Integer) As Integer


'''''''''''''''''''''''
' Windows API declarations and constants

Type rectangle
  Left As Integer
  Top As Integer
  Right As Integer
  Bottom As Integer
End Type

Global Const DT_TOP = 0
Global Const DT_LEFT = 0
Global Const DT_CENTER = &H1
Global Const DT_RIGHT = &H2
Global Const DT_VCENTER = &H4
Global Const DT_BOTTOM = &H8
Global Const DT_WORDBREAK = &H10
Global Const DT_SINGLELINE = &H20
Global Const DT_EXPANDTABS = &H40
Global Const DT_TABSTOP = &H80
Global Const DT_NOCLIP = &H100
Global Const DT_EXTERNALLEADING = &H200
Global Const DT_CALCRECT = &H400
Global Const DT_NOPREFIX = &H800
Global Const DT_INTERNAL = &H1000

Global Const SRCCOPY = &HCC0020

Global Const ES_PASSWORD = &H20
Global Const WM_USER = 1024
Global Const EM_SETPASSWORD = WM_USER + 28
Global Const EM_SETTABSTOPS = WM_USER + 27
Global Const GWL_STYLE = -16

Declare Sub DrawText Lib "User" (ByVal hDC As Integer, ByVal text As String, ByVal length As Integer, Box As rectangle, ByVal Formcode As Integer)
Declare Sub BitBlt Lib "Gdi" (ByVal hDestDC As Integer, ByVal X As Integer, ByVal Y As Integer, ByVal w As Integer, ByVal h As Integer, ByVal hSrcDC As Integer, ByVal XSrc As Integer, ByVal YSrc As Integer, ByVal dwRop As Long)

Declare Function GetWindowLong Lib "User" (ByVal hwnd%, ByVal nIndex%) As Long
Declare Function SetWindowLong Lib "User" (ByVal hwnd%, ByVal nIndex%, ByVal NewLong&) As Long
Declare Function SendMessage Lib "user" (ByVal hwnd%, ByVal msg%, ByVal wp%, lp As Any) As Long
Declare Function GetFocus Lib "User" () As Integer
Declare Function GetParent Lib "User" (ByVal hwnd%) As Integer
Declare Function GetDialogBaseUnits Lib "User" () As Long

Declare Sub SetCapture Lib "User" (ByVal hwnd As Integer)
Declare Sub ReleaseCapture Lib "User" ()

